* Created September 2019 to allow scoring of wealth tax proposals
* with separate brackets for singles vs married (as in Sanders proposal)

* data wealth.dta is a dataset of the wealth of US families in 2019
* it combines the DINA 2016 dataset and SCF 2016 aged to 2019 (weighted 50/50 each)
* it adds the Forbes 400 2018 list (and removes SCF and DINA records above the Forbes threshold)
* the unit is the family unit (not the individual adult)
* networth is true net worth in the data, weight is population weight, married is dummy for marital status
* (marital status for all Forbes 400 families is set to 1 to be conservative in tax estimation)
* data denotes the data source for the record
* complete details on the creation of the file is provided at http://wealthtaxsimulator.org/
* note that the online tax simulator does not allow to have differentiated brackets for singles vs. married
* (hence the need to rely directly on the micro data and program here)

* parameters for the Sanders wealth tax

* evasion tax rate
global evasion=.16	  
* tax parameters (thresholds in $m)
global z1=32
global z2=50
global z3=250
global z4=500
global z5=1000
global z6=2500
global z7=5000
global z8=10000
* marginal tax rate above each threshold
global t1=.01
global t2=.02
global t3=.03
global t4=.04
global t5=.05
global t6=.06
global t7=.07
global t8=.08
   
use  wealth.dta, clear

* wealth variable is the wealth (express in $m) subject to tax factoring in evasion 
gen wealth=networth*(1-$evasion)*1e-6

* computing the Sanders wealth tax (half brackets for singles) in variable tax
replace wealth=2*wealth if married==0
gen tax=0
replace tax=$t1*max(wealth-$z1,0)+($t2-$t1)*max(wealth-$z2,0)+($t3-$t2)*max(wealth-$z3,0)+($t4-$t3)*max(wealth-$z4,0)+($t5-$t4)*max(wealth-$z5,0)+($t6-$t5)*max(wealth-$z6,0)+($t7-$t6)*max(wealth-$z7,0)+($t8-$t7)*max(wealth-$z8,0)
replace wealth=wealth/2 if married==0
replace tax=tax/2 if married==0
replace tax=tax*1e+6

sum tax [w=weight] if tax>0
display r(sum)*1e-9

* statistics by brackets: Sanders plan (singles are pooled with married in each tax bracket)
gen wealthold=wealth
replace wealth=wealth*2 if married==0
global z9=1e+10
foreach i of numlist 1/8 {
	local j=`i'+1
	quietly sum wealthold  [w=weight] if wealth>=${z`i'} & wealth<${z`j'}
	local wealth=r(sum)*1e-3
	quietly sum  tax [w=weight] if wealth>=${z`i'} & wealth<${z`j'}
	local tax=r(sum)*1e-9
	display "Marginal Tax Rate " `i' "%  " "Bracket  $"${z`i'} "m-$" ${z`j'} "m  Number of taxpayers = " r(sum_w) " Total Wealth = " `wealth' " Total tax = " `tax'
}
quietly sum wealthold [w=weight] if wealth>=$z1
local wealth=r(sum)*1e-3
quietly sum  tax [w=weight] if wealth>=$z1
local tax=r(sum)*1e-9

display "Grand Total"  "    Number of taxpayers = " r(sum_w) " Total Wealth = " `wealth' " Total tax = " `tax'
replace wealth=wealth/2 if married==0

* statistics by brackets: Warren plan 
* computing the Warren wealth tax (same brackets for singles and married)
gen warrentax=.02*max(wealth-50,0)+(.03-.02)*max(wealth-1000,0)
replace warrentax=warrentax*1e+6

quietly sum wealth  [w=weight] if wealth>=50 & wealth<1000
local wealth=r(sum)*1e-3
quietly sum warrentax [w=weight] if wealth>=50 & wealth<1000
local tax=r(sum)*1e-9
display "Marginal Tax Rate 2%"   "Bracket  $50m-$1000m "  " Number of taxpayers = " r(sum_w) " Total Wealth = " `wealth' " Total tax = " `tax'
quietly sum wealth [w=weight] if wealth>=1000 
local wealth=r(sum)*1e-3
quietly sum warrentax [w=weight] if wealth>=1000 
local tax=r(sum)*1e-9
display "Marginal Tax Rate 3%"   "Bracket  $1000m+ "  " Number of taxpayers = " r(sum_w) " Total Wealth = " `wealth' " Total tax = " `tax'
quietly sum wealth [w=weight] if wealth>=50 
local wealth=r(sum)*1e-3
quietly sum warrentax [w=weight] if wealth>=50 
local tax=r(sum)*1e-9
display "Grand Total"  "    Number of taxpayers = " r(sum_w) " Total Wealth = " `wealth' " Total tax = " `tax'





